@@ -2,13 +2,19 @@ library(origami)
 library(data.table)
 context("Overall Test")
 
+r_major <- as.numeric(R.Version()$major)
+r_minor <- as.numeric(R.Version()$minor)
+if (r_major == 3 && r_minor < 6) {
+  cvmse_result <- 13.32
+} else {
+  cvmse_result <- 14.11
+}
 set.seed(1)
-
 data(mtcars)
 
-# resubstitution MSE
+# re-substitution MSE
 r <- lm(mpg ~ ., data = mtcars)
-simple_resub_MSE <- mean(resid(r) ^ 2)
+simple_resub_MSE <- mean(resid(r)^2)
 
 # function to calculate cross-validated squared error
 cvlm <- function(fold) {
@@ -17,7 +23,7 @@ cvlm <- function(fold) {
 
   r <- lm(mpg ~ ., data = train_data)
   preds <- predict(r, newdata = valid_data)
-  list(coef = data.frame(t(coef(r))), SE = ((preds - valid_data$mpg) ^ 2))
+  list(coef = data.frame(t(coef(r))), SE = ((preds - valid_data$mpg)^2))
 }
 
 # replicate the resubstitution estimate
@@ -33,5 +39,5 @@ folds <- make_folds(mtcars)
 results <- cross_validate(cvlm, folds)
 cv_MSE <- mean(results$SE)
 test_that("CV MSE matches previous value", {
-  expect_equal(cv_MSE, 13.32, tolerance = 0.01)
+  expect_equal(cv_MSE, cvmse_result, tolerance = 0.01)
 })
